"""
MLSTRUCTFP - TYPES

Define globals types used by the code.
"""

# noinspection PyUnresolvedReferences
from typing import Union, TYPE_CHECKING, List, Dict, Tuple, Optional, Any

# Types
NumberType = Union[int, float]

# Instances
NumberInstance = (int, float)
VectorInstance = (list, tuple)
